Package: dsBase
Title: DataSHIELD server site base functions
Description: DataSHIELD server site base functions.
Version: 6.1.1
Author: DataSHIELD Developers <datashield@newcastle.ac.uk>
Maintainer: DataSHIELD Developers <datashield@newcastle.ac.uk>
License: GPL-3
Depends: R (>= 3.5.0)
Imports: RANN, nlme, stringr, lme4, dplyr, reshape2
AggregateMethods: asFactorDS1, asListDS, boxPlotGGDS, checkNegValueDS,
        classDS, corTestDS, corDS, covDS, dataFrameSubsetDS1,
        densityGridDS, dimDS, glmDS1, glmDS2, glmerSLMADS2,
        glmPredictDS.ag, glmSLMADS1, glmSLMADS2, glmSummaryDS.ag,
        heatmapPlotDS, histogramDS1, histogramDS2, lsDS, isNaDS,
        isValidDS, kurtosisDS1, kurtosisDS2, lengthDS, levelsDS,
        lexisDS1, listDisclosureSettingsDS, lmerSLMADS2, matrixDetDS1,
        meanDS, meanSdGpDS, messageDS, namesDS, numNaDS,
        quantileMeanDS, rangeDS, rmDS, scatterPlotDS, scoreVectDS,
        setSeedDS, skewnessDS1, skewnessDS2, table1DDS, table2DDS,
        tableDS, tableDS2, tapplyDS, testObjExistsDS, tTestFDS2, varDS,
        colnamesDS, exists=base::exists,
        is.character=base::is.character, is.factor=base::is.factor,
        is.list=base::is.list, is.null=base::is.null,
        is.numeric=base::is.numeric, NROW=base::NROW,
        t.test=stats::t.test
AssignMethods: absDS, asCharacterDS, asDataMatrixDS, asFactorDS,
        asFactorDS2, asIntegerDS, asListDS, asLogicalDS, asMatrixDS,
        asNumericDS, BooleDS, boxPlotGG_data_TreatmentDS,
        boxPlotGG_data_Treatment_numericDS, cbindDS, cDS,
        changeRefGroupDS, completeCasesDS, dataFrameDS,
        dataFrameFillDS, dataFrameSortDS, dataFrameSubsetDS2,
        glmerSLMADS.assign, glmPredictDS.as, glmSLMADS.assign,
        glmSummaryDS.as, getWGSRDS, listDS, lexisDS2, lexisDS3,
        lmerSLMADS.assign, matrixDetDS2, matrixDiagDS,
        matrixDimnamesDS, matrixDS, matrixInvertDS, matrixMultDS,
        matrixTransposeDS, mergeDS, rbindDS, rBinomDS, recodeLevelsDS,
        recodeValuesDS, repDS, replaceNaDS, reShapeDS, rNormDS,
        rowColCalcDS, rPoisDS, rUnifDS, sampleDS, seedDS, seqDS,
        sqrtDS, subsetByClassDS, subsetDS, tableDS.assign,
        tapplyDS.assign, unListDS, as.character=base::as.character,
        as.null=base::as.null, as.numeric=base::as.numeric,
        attach=base::attach, c=base::c, cbind=base::cbind,
        complete.cases=stats::complete.cases, exp=base::exp,
        list=base::list, log=base::log, rep=base::rep, sum=base::sum,
        unlist=base::unlist
Options: datashield.privacyLevel=5, default.nfilter.glm=0.33,
        default.nfilter.kNN=3, default.nfilter.string=80,
        default.nfilter.subset=3, default.nfilter.stringShort=20,
        default.nfilter.tab=3, default.nfilter.noise=0.25,
        default.nfilter.levels=0.33
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2021-04-18 17:54:46 UTC; yannick
