# Generated by roxygen2: do not edit by hand

export(BooleDS)
export(absDS)
export(asCharacterDS)
export(asDataMatrixDS)
export(asFactorDS1)
export(asFactorDS2)
export(asFactorSimpleDS)
export(asIntegerDS)
export(asListDS)
export(asLogicalDS)
export(asMatrixDS)
export(asNumericDS)
export(aucDS)
export(blackBoxDS)
export(blackBoxRanksDS)
export(boxPlotGGDS)
export(boxPlotGG_data_TreatmentDS)
export(boxPlotGG_data_Treatment_numericDS)
export(bp_standardsDS)
export(cDS)
export(cbindDS)
export(changeRefGroupDS)
export(checkNegValueDS)
export(checkPermissivePrivacyControlLevel)
export(classDS)
export(colnamesDS)
export(completeCasesDS)
export(corDS)
export(corTestDS)
export(covDS)
export(dataFrameDS)
export(dataFrameFillDS)
export(dataFrameSortDS)
export(dataFrameSubsetDS1)
export(dataFrameSubsetDS2)
export(densityGridDS)
export(dimDS)
export(dmtC2SDS)
export(elsplineDS)
export(extractQuantilesDS1)
export(extractQuantilesDS2)
export(gamlssDS)
export(getWGSRDS)
export(glmDS1)
export(glmDS2)
export(glmPredictDS.ag)
export(glmPredictDS.as)
export(glmSLMADS.assign)
export(glmSLMADS1)
export(glmSLMADS2)
export(glmSummaryDS.ag)
export(glmSummaryDS.as)
export(glmerSLMADS.assign)
export(glmerSLMADS2)
export(heatmapPlotDS)
export(hetcorDS)
export(histogramDS1)
export(histogramDS2)
export(igb_standardsDS)
export(isNaDS)
export(isValidDS)
export(kurtosisDS1)
export(kurtosisDS2)
export(lengthDS)
export(levelsDS)
export(lexisDS1)
export(lexisDS2)
export(lexisDS3)
export(listDS)
export(listDisclosureSettingsDS)
export(lmerSLMADS.assign)
export(lmerSLMADS2)
export(lsDS)
export(lsplineDS)
export(matrixDS)
export(matrixDetDS1)
export(matrixDetDS2)
export(matrixDiagDS)
export(matrixDimnamesDS)
export(matrixInvertDS)
export(matrixMultDS)
export(matrixTransposeDS)
export(mdPatternDS)
export(meanDS)
export(meanSdGpDS)
export(mergeDS)
export(messageDS)
export(metadataDS)
export(miceDS)
export(minMaxRandDS)
export(namesDS)
export(nsDS)
export(numNaDS)
export(qlsplineDS)
export(quantileMeanDS)
export(rBinomDS)
export(rNormDS)
export(rPoisDS)
export(rUnifDS)
export(rangeDS)
export(ranksSecureDS1)
export(ranksSecureDS2)
export(ranksSecureDS3)
export(ranksSecureDS4)
export(ranksSecureDS5)
export(rbindDS)
export(reShapeDS)
export(recodeLevelsDS)
export(recodeValuesDS)
export(repDS)
export(replaceNaDS)
export(rmDS)
export(rowColCalcDS)
export(sampleDS)
export(scatterPlotDS)
export(seqDS)
export(setSeedDS)
export(skewnessDS1)
export(skewnessDS2)
export(sqrtDS)
export(subsetByClassDS)
export(subsetDS)
export(table1DDS)
export(table2DDS)
export(tableDS)
export(tableDS.assign)
export(tableDS2)
export(tapplyDS)
export(tapplyDS.assign)
export(testObjExistsDS)
export(unListDS)
export(uniqueDS)
export(varDS)
export(vectorDS)
import(childsds)
import(dplyr)
import(gamlss)
import(gamlss.dist)
import(mice)
importFrom(gamlss.dist,pST3)
importFrom(gamlss.dist,qST3)
