\name{nais1.ds}
\alias{nais1.ds}
\title{checks for NAs in a vector}
\usage{
  nais1.ds(xvect)
}
\arguments{
  \item{xvect}{a numeric or factor vector}
}
\value{
  a factor
}
\description{
  checks for NAs in a vector
}
\author{
  Burton, P.; Gaye, A.
}

