\name{names.ds}
\alias{names.ds}
\title{Returns the names of a list}
\usage{
  names.ds(xlist)
}
\arguments{
  \item{xlist}{a list}
}
\value{
  a character vector or NULL if the list does not have
  names
}
\description{
  Returns the names of a list
}
\details{
  This is similar to R base function \code{names} but
  restricted to list types only.
}
\author{
  Gaye, A.
}

